@@ -6,7 +6,7 @@ log = logging.getLogger(__name__)
 
 def list_products(self) -> dict:
     """
-    https://developer.paddle.com/api-reference/product-api/products/getproducts
-    """
+    `List Products Paddle docs <https://developer.paddle.com/api-reference/product-api/products/getproducts>`_
+    """  # NOQA: E501
     url = urljoin(self.vendors_v2, 'product/get_products')
     return self.post(url=url)
