@@ -10,10 +10,10 @@ def get_user_history(
     email: str,
     vendor_id: int = None,
     product_id: int = None
-) -> dict:
-    """
-    https://developer.paddle.com/api-reference/checkout-api/user-history/getuserhistory
+) -> str:
     """
+    `Get User History Paddle docs <https://developer.paddle.com/api-reference/checkout-api/user-history/getuserhistory>`_
+    """  # NOQA: E501
     url = urljoin(self.checkout_v2, 'user/history')
 
     params = {'email': email}   # type: Dict[str, Union[str, int]]
