@@ -5,8 +5,8 @@ from .types import DatetimeType, DateType
 
 def validate_date(value: DateType, field_name: str) -> str:
     date_format = '%Y-%m-%d'
+    error_message = '{0} must be a datetime/date object or string in format YYYY-MM-DD'.format(field_name)  # NOQA: E501
     if isinstance(value, str):
-        error_message = '{0} must be a datetime/data object or string in format YYYY-MM-DD'.format(field_name)  # NOQA: E501
         try:
             datetime.strptime(value, date_format)
         except ValueError:
@@ -21,8 +21,8 @@ def validate_date(value: DateType, field_name: str) -> str:
 
 def validate_datetime(value: DatetimeType, field_name: str) -> str:
     datetime_format = '%Y-%m-%d %H:%M:%S'
+    error_message = '{0} must be a datetime object or string in format YYYY-MM-DD HH:MM:SS'.format(field_name)  # NOQA: E501
     if isinstance(value, str):
-        error_message = '{0} must be a datetime object or string in format YYYY-MM-DD HH:MM:SS'.format(field_name)  # NOQA: E501
         try:
             datetime.strptime(value, datetime_format)
         except ValueError:
